﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class Mover : MonoBehaviour
{
    [SerializeField] private LayerMask whatToHit;
    [SerializeField] private Transform groundDetector;
    [SerializeField] private float detectionRadius = 0.5f;
    [SerializeField] public Rigidbody2D myRB;

    private Animator myAnim;
    
    public bool onGround = false;

    void Start()
    {
        myAnim = GetComponent<Animator>();
        if (myRB == null)
            myRB = GetComponent<Rigidbody2D>();
    }

    void FixedUpdate()
    {
        if (Physics2D.OverlapCircle(groundDetector.position, detectionRadius, whatToHit))
        {
            SetOnGround(true);
        }
        else
            SetOnGround(false);
        
        myAnim.SetFloat("HorizontalSpeed", Mathf.Abs(myRB.velocity.x / 10f));
        myAnim.SetFloat("VerticalSpeed", myRB.velocity.y / 15f);
    }
    

    public void Forcer(Vector2 forceVector)
    {
        myRB.AddForce(forceVector);
    }
    
    public void HorizontalMover(float prefferedHorizontalSpeed, float maxForce = 1000)
    {
        if (Mathf.Sign(prefferedHorizontalSpeed) == Mathf.Sign(myRB.velocity.x) && Mathf.Abs(myRB.velocity.x) > Mathf.Abs(prefferedHorizontalSpeed))
            return;//for Speeding specially On Dash
        
        if (Mathf.Sign(prefferedHorizontalSpeed) * Mathf.Sign(myRB.velocity.x) == -1 && prefferedHorizontalSpeed != 0)
            myRB.angularVelocity = 0;
        
        float force = (prefferedHorizontalSpeed - myRB.velocity.x) / Time.deltaTime;
        if (Mathf.Abs(force) > Mathf.Abs(maxForce))
            force = Mathf.Abs(maxForce) * Mathf.Sign(force);
        force *= myRB.mass;
        myRB.AddForce(force * Vector2.right);
        
    }

    public void Jump(float jumpHeight)
    {
        if (onGround)
        {
            float startVelocity = Mathf.Pow(Mathf.Abs(2 * jumpHeight * Physics2D.gravity.y), 0.5f);
            myRB.velocity += (startVelocity - myRB.velocity.y) * Vector2.up;
        }
    }

    private void SetOnGround(bool g)
    {
        if (g != onGround)
        {
            onGround = g;
            myAnim.SetBool("OnGround", g);
        }
    }
    
    void OnDrawGizmos()
    {
        if (groundDetector != null)
        {
            Gizmos.color = Color.green;
            Gizmos.DrawWireSphere(groundDetector.position, detectionRadius);
        }
    }
}
