﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.Events;

public class PlatformMover : MonoBehaviour
{
    [SerializeField] private Transform movingPart;
    [SerializeField] private float moveDuration;
    [SerializeField] private Transform secontTransform;
    [SerializeField] private UnityEvent onChangeState;
    private Vector3 firstPosition;
    private bool isInSecond = false;
    private Coroutine myCoroutine;
    
    // Start is called before the first frame update
    void Start()
    {
        firstPosition = movingPart.position;
    }

    public void FirstToSecond()
    {
        if (isInSecond)
            return;
        isInSecond = false;
        if (myCoroutine != null)
        {
            StopCoroutine(myCoroutine);
        }
        myCoroutine = StartCoroutine(MoveToNextPosition());
        
    }
    
    public void SecondToFirst()
    {
        if (!isInSecond)
            return;
        isInSecond = true;
        if (myCoroutine != null)
        {
            StopCoroutine(myCoroutine);
        }
        myCoroutine = StartCoroutine(MoveToNextPosition());
        
    }
    
    
    private IEnumerator MoveToNextPosition()
    {
        float timer = 0;
        while (timer < moveDuration)
        {
            timer += Time.deltaTime;
            if (!isInSecond)
            {
                movingPart.position = Vector3.Lerp(firstPosition, secontTransform.position, timer / moveDuration);
            }
            else
            {
                movingPart.position = Vector3.Lerp(secontTransform.position, firstPosition, timer / moveDuration);
            }

            yield return null;
        }

        isInSecond = !isInSecond;
        myCoroutine = null;
    }
}
