﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class PlayerController : MonoBehaviour
{
    [SerializeField] private float jumpHeight;
    [SerializeField] private float moveSpeed;
    [SerializeField] private float maxHorizontalForce = 100;
    [Space]
    [SerializeField] private Transform visual;
    [Space]
    [SerializeField] private bool canGlide = false;
    [SerializeField] private float glidePower = 10;
    [Space]
    [SerializeField] private bool canDash = false;
    [SerializeField] private float dashAmount = 5;
    [SerializeField] private float dashDuration = 1.5f;
    [SerializeField] private float dashCoolDownDuration = 1;
    [Space]
    [SerializeField] private TrailRenderer dashTrail;

    [SerializeField] private Mover myMover;
    public bool faceRight = true;
    private bool isGliding = false;
    private Animator myAnim;
    private float dashSpeedMultiplier = 1;
    private bool isDashing = false;
    private Coroutine lastTrailShow;
    void Start()
    {
        myAnim = GetComponent<Animator>();
        if (myMover == null)
            myMover = GetComponent<Mover>();
    }

    // Update is called once per frame
    void FixedUpdate()
    {
        float horizAxis = Input.GetAxis("Horizontal");
        myMover.HorizontalMover(horizAxis * moveSpeed * dashSpeedMultiplier, maxHorizontalForce);



        
        if (visual != null)
        {
            if (horizAxis > 0)
            {
                visual.localScale = new Vector3(1, 1, 1);
                faceRight = true;
            }
            else if (horizAxis < 0)
            {
                visual.localScale = new Vector3(-1, 1, 1);
                faceRight = false;
            }
        }
        

        if (canGlide && !myMover.onGround)
        {
            if (Input.GetButtonDown("Jump"))
            {
                isGliding = true;
                myAnim.SetBool("IsGliding", true);
            }
            else if (Input.GetButtonUp("Jump"))
            {
                isGliding = false;
                myAnim.SetBool("IsGliding", false);
            }

            if (isGliding)
            {
                if (myMover.myRB.velocity.y < 0)
                    myMover.Forcer(Vector2.up * glidePower * Time.deltaTime);
            }
        }
        else
        {
            isGliding = false;
            myAnim.SetBool("IsGliding", false);
        }
    }
    
    void Update()
    {


        if (canDash)
        {
            if (!isDashing && Input.GetButtonDown("Fire1"))
            {
                StartCoroutine(MultiplySpeedInDuration(dashDuration, dashAmount));
                if (lastTrailShow != null)
                    StopCoroutine(lastTrailShow);
                lastTrailShow = StartCoroutine(TrailShow(4));
            }
                
        }

        if (Input.GetButtonDown("Jump"))
        {
            Jump();
        }
    }
    

    private IEnumerator MultiplySpeedInDuration(float duration, float speedMultiplier)
    {
        
            
        isDashing = true;
        float timer = 0;
        while (timer < duration)
        {
            timer += Time.deltaTime;
            dashSpeedMultiplier = Mathf.Lerp(speedMultiplier, 1, timer / duration);
            
            yield return null;
        }
        dashSpeedMultiplier = 1;
        timer = 0;
        while (timer < dashCoolDownDuration)
        {
            timer += Time.deltaTime;
            yield return null;
        }

        isDashing = false;
    }

    private IEnumerator TrailShow(float duration)
    {
        if (dashTrail != null)
        {
            dashTrail.enabled = true;
            dashTrail.startColor = Color.white;

            float timer = 0;
            while (timer < duration)
            {
                timer += Time.deltaTime;
                dashTrail.startColor = Color.Lerp(dashTrail.startColor, new Color(0, 0, 0, 0), timer / duration);

                yield return null;
            }
        }
    }
    

    public void Jump()
    {
        myMover.Jump(jumpHeight);
    }
    public void Jump(float height)
    {
        myMover.Jump(height);
    }

    public void PlayAudio(AudioClip ac)
    {
        FindObjectOfType<AudioSource>().PlayOneShot(ac);
    }
    
}
